@@ -32,7 +32,7 @@
 #include <gtkdatabox_bars.h>
 #include <gtkdatabox_grid.h>
 #include <gtkdatabox_cross_simple.h>
-#include <gtkdatabox_marker.h>
+#include <gtkdatabox_markers.h>
 #include "gpmudmon.h"
 
 extern int count_timer(gpointer data);
@@ -67,60 +67,56 @@ charge_changed_cb(gpointer d)
 static gint
 motion_notify_left_cb(PmudData *pd, GdkEventMotion *event)
 {
-  GtkDataboxCoord coord;
-  GtkDataboxValue value, top_left, bottom_right;
+	gfloat value_x, value_y;
   gchar *text;
 
-  coord.x = event->x;
-  coord.y = event->y;
+	value_x = gtk_databox_pixel_to_value_x (GTK_DATABOX(pd->databox_left), event->x);
+	value_y = gtk_databox_pixel_to_value_y (GTK_DATABOX(pd->databox_left), event->y);
 
-  value = gtk_databox_value_from_coord (GTK_DATABOX(pd->databox_left), coord);
-
-	gtk_databox_get_visible_canvas (GTK_DATABOX(pd->databox_left), &top_left, &bottom_right);
-
-	if(value.x*pd->graphupdatetime/1000.0 > 60.0) {
-		int minutes = (int) (value.x*(float)pd->graphupdatetime/1000.0/60.0);
-		int seconds = (int) ((int)(value.x*(float)pd->graphupdatetime/1000.0)%60);
+	if(value_x*pd->graphupdatetime/1000.0 > 60.0) {
+		int minutes = (int) (value_x*(float)pd->graphupdatetime/1000.0/60.0);
+		int seconds = (int) ((int)(value_x*(float)pd->graphupdatetime/1000.0)%60);
 		text=g_strdup_printf(_("%d min %d sec ago"), /*(int)event->x*/ minutes, seconds);
 	} else {
-		text=g_strdup_printf(_("%d sec ago"), (int) (value.x*(float)pd->graphupdatetime/1000));
+		text=g_strdup_printf(_("%d sec ago"), (int) (value_x*(float)pd->graphupdatetime/1000));
 	}
   gtk_entry_set_text(GTK_ENTRY(pd->xcoord_left), text);
   g_free((gpointer) text);
-  text=g_strdup_printf("%.3fV / %.3fA", value.y/100.0, value.y/1000.0);
+  text=g_strdup_printf("%.3fV / %.3fA", value_y/100.0, value_y/1000.0);
   gtk_entry_set_text(GTK_ENTRY(pd->ycoord_left), text);
   g_free((gpointer) text);
 
-	int index = (int) (value.x + 0.5);
+	int index = (int) (value_x + 0.5);
 	guint position;
-	pd->markerx_left[0] = value.x;
+	pd->markerx_left[0] = value_x;
 	pd->markery_left[0] = pd->graph_data_left->current[index];
-	pd->markerx_left[1] = value.x;
+	pd->markerx_left[1] = value_x;
 	pd->markery_left[1] = pd->graph_data_left->voltage[index];
 
 	if(event->x > 475)
-		position = GTK_DATABOX_TEXT_NW;
+		position = GTK_DATABOX_MARKERS_TEXT_NW;
 	else if(event->x < 25)
-		position = GTK_DATABOX_TEXT_NE;
+		position = GTK_DATABOX_MARKERS_TEXT_NE;
 	else
-		position = GTK_DATABOX_TEXT_N;
+		position = GTK_DATABOX_MARKERS_TEXT_N;
 	text = g_strdup_printf ("%.3f A", pd->graph_data_left->current[index]/1000.0);
-  gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_left), 0,
+  gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_left), 0,
                                 position, text, TRUE);
   g_free((gpointer) text);
 
 	if(event->x > 475)
-		position = GTK_DATABOX_TEXT_SW;
+		position = GTK_DATABOX_MARKERS_TEXT_SW;
 	else if(event->x < 25)
-		position = GTK_DATABOX_TEXT_SE;
+		position = GTK_DATABOX_MARKERS_TEXT_SE;
 	else
-		position = GTK_DATABOX_TEXT_S;
+		position = GTK_DATABOX_MARKERS_TEXT_S;
 	text = g_strdup_printf ("%.3f V", pd->graph_data_left->voltage[index]/100.0);
-  gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_left), 1,
+  gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_left), 1,
                                 position, text, TRUE);
   g_free((gpointer) text);
 
-	gtk_databox_redraw(GTK_DATABOX(pd->databox_left));
+//	gtk_databox_redraw(GTK_DATABOX(pd->databox_left));
+	gtk_widget_queue_draw(pd->databox_left);
 
   return FALSE;
 
@@ -129,60 +125,57 @@ motion_notify_left_cb(PmudData *pd, GdkEventMotion *event)
 static gint
 motion_notify_right_cb(PmudData *pd, GdkEventMotion *event)
 {
-  GtkDataboxCoord coord;
-  GtkDataboxValue value, top_left, bottom_right;
+	gfloat value_x, value_y;
   gchar *text;
 
-  coord.x = event->x;
-  coord.y = event->y;
+	value_x = gtk_databox_pixel_to_value_x (GTK_DATABOX(pd->databox_left), event->x);
+	value_y = gtk_databox_pixel_to_value_y (GTK_DATABOX(pd->databox_left), event->y);
 
-  value = gtk_databox_value_from_coord (GTK_DATABOX(pd->databox_right), coord);
 
-	gtk_databox_get_visible_canvas (GTK_DATABOX(pd->databox_right), &top_left, &bottom_right);
-
-	if(value.x*pd->graphupdatetime/1000.0 > 60.0) {
-		int minutes = (int) (value.x*(float)pd->graphupdatetime/1000.0/60.0);
-		int seconds = (int) ((int)(value.x*(float)pd->graphupdatetime/1000.0)%60);
-		text=g_strdup_printf(_("%d min %d sec ago"), (int)event->x /*minutes*/, seconds);
+	if(value_x*pd->graphupdatetime/1000.0 > 60.0) {
+		int minutes = (int) (value_x*(float)pd->graphupdatetime/1000.0/60.0);
+		int seconds = (int) ((int)(value_x*(float)pd->graphupdatetime/1000.0)%60);
+		text=g_strdup_printf(_("%d min %d sec ago"), /*(int)event->x*/ minutes, seconds);
 	} else {
-		text=g_strdup_printf(_("%d sec ago"), (int) (value.x*(float)pd->graphupdatetime/1000));
+		text=g_strdup_printf(_("%d sec ago"), (int) (value_x*(float)pd->graphupdatetime/1000));
 	}
   gtk_entry_set_text(GTK_ENTRY(pd->xcoord_right), text);
   g_free((gpointer) text);
-  text=g_strdup_printf("%.3fV / %.3fA", value.y/100.0, value.y/1000.0);
+  text=g_strdup_printf("%.3fV / %.3fA", value_y/100.0, value_y/1000.0);
   gtk_entry_set_text(GTK_ENTRY(pd->ycoord_right), text);
   g_free((gpointer) text);
 
-	int index = (int) (value.x + 0.5);
+	int index = (int) (value_x + 0.5);
 	guint position;
-	pd->markerx_right[0] = value.x;
+	pd->markerx_right[0] = value_x;
 	pd->markery_right[0] = pd->graph_data_right->current[index];
-	pd->markerx_right[1] = value.x;
+	pd->markerx_right[1] = value_x;
 	pd->markery_right[1] = pd->graph_data_right->voltage[index];
 
 	if(event->x > 475)
-		position = GTK_DATABOX_TEXT_NW;
+		position = GTK_DATABOX_MARKERS_TEXT_NW;
 	else if(event->x < 25)
-		position = GTK_DATABOX_TEXT_NE;
+		position = GTK_DATABOX_MARKERS_TEXT_NE;
 	else
-		position = GTK_DATABOX_TEXT_N;
+		position = GTK_DATABOX_MARKERS_TEXT_N;
 	text = g_strdup_printf ("%.3f A", pd->graph_data_right->current[index]/1000.0);
-  gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_right), 0,
+  gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_right), 0,
                                 position, text, TRUE);
   g_free((gpointer) text);
 
 	if(event->x > 475)
-		position = GTK_DATABOX_TEXT_SW;
+		position = GTK_DATABOX_MARKERS_TEXT_SW;
 	else if(event->x < 25)
-		position = GTK_DATABOX_TEXT_SE;
+		position = GTK_DATABOX_MARKERS_TEXT_SE;
 	else
-		position = GTK_DATABOX_TEXT_S;
+		position = GTK_DATABOX_MARKERS_TEXT_S;
 	text = g_strdup_printf ("%.3f V", pd->graph_data_right->voltage[index]/100.0);
-  gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_right), 1,
+  gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_right), 1,
                                 position, text, TRUE);
   g_free((gpointer) text);
 
-	gtk_databox_redraw(GTK_DATABOX(pd->databox_right));
+//	gtk_databox_redraw(GTK_DATABOX(pd->databox_right));
+	gtk_widget_queue_draw(pd->databox_left);
 
   return FALSE;
 
@@ -190,6 +183,7 @@ motion_notify_right_cb(PmudData *pd, GdkEventMotion *event)
 
 void
 set_graph_scale_left(PmudData *pd) {
+/*
 	GtkDataboxValue min;
 	GtkDataboxValue max;
 
@@ -198,10 +192,13 @@ set_graph_scale_left(PmudData *pd) {
 	max.x = 0;
 	max.y = -2000.0;
 	gtk_databox_set_canvas (GTK_DATABOX(pd->databox_left), min, max);
+*/
+	gtk_databox_set_total_limits (GTK_DATABOX(pd->databox_left), (float) pd->numsamples, 0, 2000.0, -2000.0);
 }
 
 void
 set_graph_scale_right(PmudData *pd) {
+/*
 	GtkDataboxValue min;
 	GtkDataboxValue max;
 
@@ -210,16 +207,14 @@ set_graph_scale_right(PmudData *pd) {
 	max.x = 0;
 	max.y = -2000.0;
 	gtk_databox_set_canvas (GTK_DATABOX(pd->databox_right), min, max);
+*/
+	gtk_databox_set_total_limits (GTK_DATABOX(pd->databox_right), (float) pd->numsamples, 0, 2000.0, -2000.0);
 }
 
 void
 create_graph_left(PmudData *pd) {
-	gfloat *markX;
-	gfloat *markY;
-
-	GtkDataboxGraph *graph, *graph2, *graph3;
+	GtkDataboxGraph *graph, *graph2;
 	GdkColor color;
-	gint i, j;
 
 	if(!pd->databox_left)
 		return;
@@ -255,25 +250,21 @@ create_graph_left(PmudData *pd) {
   color.green = 65535;
   color.blue = 0;
 
-	pd->marker_left = gtk_databox_marker_new (2, pd->markerx_left, pd->markery_left, &color, 7,
-	                                GTK_DATABOX_MARKER_TRIANGLE);
-	gtk_databox_marker_set_position (GTK_DATABOX_MARKER (pd->marker_left), 0,
-	                                 GTK_DATABOX_MARKER_N);
-	gtk_databox_marker_set_position (GTK_DATABOX_MARKER (pd->marker_left), 1,
-	                                 GTK_DATABOX_MARKER_S);
-//	shift_marker (GTK_DATABOX (pd->databox_left), GTK_DATABOX_MARKER (pd->marker_left));
+	pd->marker_left = gtk_databox_markers_new (2, pd->markerx_left, pd->markery_left, &color, 7,
+	                                GTK_DATABOX_MARKERS_TRIANGLE);
+	gtk_databox_markers_set_position (GTK_DATABOX_MARKERS (pd->marker_left), 0,
+	                                 GTK_DATABOX_MARKERS_N);
+	gtk_databox_markers_set_position (GTK_DATABOX_MARKERS (pd->marker_left), 1,
+	                                 GTK_DATABOX_MARKERS_S);
+//	shift_marker (GTK_DATABOX (pd->databox_left), GTK_DATABOX_MARKERS (pd->marker_left));
 	gtk_databox_graph_add (GTK_DATABOX (pd->databox_left), GTK_DATABOX_GRAPH(pd->marker_left));
 
 }
 
 void
 create_graph_right(PmudData *pd) {
-	gfloat *markX;
-	gfloat *markY;
-
-	GtkDataboxGraph *graph, *graph2, *graph3;
+	GtkDataboxGraph *graph, *graph2;
 	GdkColor color;
-	gint i, j;
 
 	if(!pd->databox_right)
 		return;
@@ -309,13 +300,13 @@ create_graph_right(PmudData *pd) {
   color.green = 65535;
   color.blue = 0;
 
-	pd->marker_right = gtk_databox_marker_new (2, pd->markerx_right, pd->markery_right, &color, 7,
-	                                GTK_DATABOX_MARKER_TRIANGLE);
-	gtk_databox_marker_set_position (GTK_DATABOX_MARKER (pd->marker_right), 0,
-	                                 GTK_DATABOX_MARKER_N);
-	gtk_databox_marker_set_position (GTK_DATABOX_MARKER (pd->marker_right), 1,
-	                                 GTK_DATABOX_MARKER_S);
-//	shift_marker (GTK_DATABOX (pd->databox_right), GTK_DATABOX_MARKER (pd->marker_right));
+	pd->marker_right = gtk_databox_markers_new (2, pd->markerx_right, pd->markery_right, &color, 7,
+	                                GTK_DATABOX_MARKERS_TRIANGLE);
+	gtk_databox_markers_set_position (GTK_DATABOX_MARKERS(pd->marker_right), 0,
+	                                 GTK_DATABOX_MARKERS_N);
+	gtk_databox_markers_set_position (GTK_DATABOX_MARKERS(pd->marker_right), 1,
+	                                 GTK_DATABOX_MARKERS_S);
+//	shift_marker (GTK_DATABOX (pd->databox_right), GTK_DATABOX_MARKERS (pd->marker_right));
 	gtk_databox_graph_add (GTK_DATABOX (pd->databox_right), GTK_DATABOX_GRAPH(pd->marker_right));
 
 }
@@ -323,13 +314,11 @@ create_graph_right(PmudData *pd) {
 void
 charge_cb(BonoboUIComponent *uic, gpointer p, const gchar *verbname)
 {
-	GtkWidget *frame, *hbox, *label, *spin_labe;
+	GtkWidget *frame, *label;
 	GtkWidget *table, *scrollbar, *ruler, *box1;
 	GtkWidget *cadre;
 	GtkWidget *tbox;
-	GtkDataboxGraph *graph, *graph2;
 	GdkColor color;
-	gint i, j;
 
 	PmudData *pd = (PmudData *) p;
 
@@ -370,23 +359,23 @@ charge_cb(BonoboUIComponent *uic, gpointer p, const gchar *verbname)
 			/* You could associate a scrollbar with a GtkDatabox widget either 
 			 * this way ...*/
 			scrollbar = gtk_hscrollbar_new (NULL);
-			gtk_databox_set_hadjustment (GTK_DATABOX (pd->databox_left),
+			gtk_databox_set_adjustment_x (GTK_DATABOX (pd->databox_left),
 	                        gtk_range_get_adjustment (GTK_RANGE (scrollbar)));
 			gtk_table_attach (GTK_TABLE (table), scrollbar, 1, 2, 2, 3,
 	                  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
 			/* or this way ... */
 			scrollbar = gtk_vscrollbar_new
-											(gtk_databox_get_vadjustment (GTK_DATABOX (pd->databox_left)));
+											(gtk_databox_get_adjustment_y (GTK_DATABOX (pd->databox_left)));
 			gtk_table_attach (GTK_TABLE (table), scrollbar, 2, 3, 1, 2,
 												GTK_FILL, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
-			ruler = gtk_hruler_new ();
+			ruler = gtk_databox_ruler_new (GTK_ORIENTATION_HORIZONTAL);
 			gtk_table_attach (GTK_TABLE (table), ruler, 1, 2, 0, 1,
 												GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
-			gtk_databox_set_hruler (GTK_DATABOX (pd->databox_left), GTK_RULER (ruler));
-			ruler = gtk_vruler_new ();
+			gtk_databox_set_ruler_x (GTK_DATABOX (pd->databox_left), GTK_DATABOX_RULER (ruler));
+			ruler = gtk_databox_ruler_new (GTK_ORIENTATION_VERTICAL);
 			gtk_table_attach (GTK_TABLE (table), ruler, 0, 1, 1, 2,
 												GTK_FILL, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
-			gtk_databox_set_vruler (GTK_DATABOX (pd->databox_left), GTK_RULER (ruler));
+			gtk_databox_set_ruler_y (GTK_DATABOX (pd->databox_left), GTK_DATABOX_RULER (ruler));
 			/* end of gtk_databox_create_box_with_scrollbars_and_rulers */
 
 			gtk_box_pack_start (GTK_BOX (box1), table, TRUE, TRUE, 0);
@@ -474,23 +463,23 @@ charge_cb(BonoboUIComponent *uic, gpointer p, const gchar *verbname)
 			/* You could associate a scrollbar with a GtkDatabox widget either 
 			 * this way ...*/
 			scrollbar = gtk_hscrollbar_new (NULL);
-			gtk_databox_set_hadjustment (GTK_DATABOX (pd->databox_right),
+			gtk_databox_set_adjustment_x (GTK_DATABOX (pd->databox_right),
 	                        gtk_range_get_adjustment (GTK_RANGE (scrollbar)));
 			gtk_table_attach (GTK_TABLE (table), scrollbar, 1, 2, 2, 3,
 	                  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
 			/* or this way ... */
 			scrollbar = gtk_vscrollbar_new
-											(gtk_databox_get_vadjustment (GTK_DATABOX (pd->databox_right)));
+											(gtk_databox_get_adjustment_y (GTK_DATABOX (pd->databox_right)));
 			gtk_table_attach (GTK_TABLE (table), scrollbar, 2, 3, 1, 2,
 												GTK_FILL, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
-			ruler = gtk_hruler_new ();
+			ruler = gtk_databox_ruler_new (GTK_ORIENTATION_HORIZONTAL);
 			gtk_table_attach (GTK_TABLE (table), ruler, 1, 2, 0, 1,
 												GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
-			gtk_databox_set_hruler (GTK_DATABOX (pd->databox_right), GTK_RULER (ruler));
-			ruler = gtk_vruler_new ();
+			gtk_databox_set_ruler_x (GTK_DATABOX (pd->databox_right), GTK_DATABOX_RULER (ruler));
+			ruler = gtk_databox_ruler_new (GTK_ORIENTATION_VERTICAL);
 			gtk_table_attach (GTK_TABLE (table), ruler, 0, 1, 1, 2,
 												GTK_FILL, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
-			gtk_databox_set_vruler (GTK_DATABOX (pd->databox_right), GTK_RULER (ruler));
+			gtk_databox_set_ruler_y (GTK_DATABOX (pd->databox_right), GTK_DATABOX_RULER (ruler));
 			/* end of gtk_databox_create_box_with_scrollbars_and_rulers */
 
 			gtk_box_pack_start (GTK_BOX (box1), table, TRUE, TRUE, 0);
