@@ -36,7 +36,7 @@
 #include "gpmudmon.h"
 #include "gtkgauge.h"
 #include <gtkdatabox.h>
-#include <gtkdatabox_marker.h>
+#include <gtkdatabox_markers.h>
 
 GtkWidget *counter;
 GtkTooltips *tooltip;
@@ -132,7 +132,7 @@ about_cb(BonoboUIComponent *uic, gpointer d, const gchar *verbname)
 	about = gnome_about_new (
 		"GNOME Pmu Monitor",
 		VERSION,
-		"(C) 2000-2007 Uwe Steinmann",
+		"(C) 2000-2008 Uwe Steinmann",
 		_("This applet displays the battery status as provided by the power mananagement unit on apple computers."),
 		authors,
 		documenters,
@@ -233,33 +233,33 @@ graph_timer(gpointer data)
 				if(pd->databox_left) {
 					gchar *text;
 					guint position;
-					GtkDataboxCoord coord;
-					GtkDataboxValue value;
-					value.x = pd->markerx_left[0];
-					value.y = 0;
-					coord = gtk_databox_coord_from_value(GTK_DATABOX(pd->databox_left), value);
+					gint16 coord_x;
+//					GtkDataboxCoord coord;
+//					coord = gtk_databox_coord_from_value(GTK_DATABOX(pd->databox_left), value);
+					coord_x = gtk_databox_value_to_pixel_x(GTK_DATABOX(pd->databox_left), pd->markerx_left[0]);
 					text = g_strdup_printf ("%.3f A", pd->graph_data_left->current[index]/1000.0);
-					if(coord.x > 475)
-						position = GTK_DATABOX_TEXT_NW;
-					else if(coord.x < 25)
-						position = GTK_DATABOX_TEXT_NE;
+					if(coord_x > 475)
+						position = GTK_DATABOX_MARKERS_TEXT_NW;
+					else if(coord_x < 25)
+						position = GTK_DATABOX_MARKERS_TEXT_NE;
 					else
-						position = GTK_DATABOX_TEXT_N;
-					gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_left), 0,
+						position = GTK_DATABOX_MARKERS_TEXT_N;
+					gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_left), 0,
 																				position, text, TRUE);
 					g_free((gpointer) text);
 					text = g_strdup_printf ("%.3f V", pd->graph_data_left->voltage[index]/100.0);
-					if(coord.x > 475)
-						position = GTK_DATABOX_TEXT_SW;
-					else if(coord.x < 25)
-						position = GTK_DATABOX_TEXT_SE;
+					if(coord_x > 475)
+						position = GTK_DATABOX_MARKERS_TEXT_SW;
+					else if(coord_x < 25)
+						position = GTK_DATABOX_MARKERS_TEXT_SE;
 					else
-						position = GTK_DATABOX_TEXT_S;
-					gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_left), 1,
+						position = GTK_DATABOX_MARKERS_TEXT_S;
+					gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_left), 1,
 																				position, text, TRUE);
 					g_free((gpointer) text);
 
-					gtk_databox_redraw(pd->databox_left);
+//					gtk_databox_redraw(pd->databox_left);
+					gtk_widget_queue_draw(pd->databox_left);
 
 					int i;
 					float charge = 0.0;
@@ -286,33 +286,31 @@ graph_timer(gpointer data)
 				if(pd->databox_right) {
 					gchar *text;
 					guint position;
-					GtkDataboxCoord coord;
-					GtkDataboxValue value;
-					value.x = pd->markerx_right[0];
-					value.y = 0;
-					coord = gtk_databox_coord_from_value(GTK_DATABOX(pd->databox_right), value);
+					gint16 coord_x;
+					coord_x = gtk_databox_value_to_pixel_x(GTK_DATABOX(pd->databox_right), pd->markerx_right[0]);
 					text = g_strdup_printf ("%.3f A", pd->graph_data_right->current[index]/1000.0);
-					if(coord.x > 475)
-						position = GTK_DATABOX_TEXT_NW;
-					else if(coord.x < 25)
-						position = GTK_DATABOX_TEXT_NE;
+					if(coord_x > 475)
+						position = GTK_DATABOX_MARKERS_TEXT_NW;
+					else if(coord_x < 25)
+						position = GTK_DATABOX_MARKERS_TEXT_NE;
 					else
-						position = GTK_DATABOX_TEXT_N;
-					gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_right), 0,
+						position = GTK_DATABOX_MARKERS_TEXT_N;
+					gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_right), 0,
 																				position, text, TRUE);
 					g_free((gpointer) text);
 					text = g_strdup_printf ("%.3f V", pd->graph_data_right->voltage[index]/100.0);
-					if(coord.x > 475)
-						position = GTK_DATABOX_TEXT_SW;
-					else if(coord.x < 25)
-						position = GTK_DATABOX_TEXT_SE;
+					if(coord_x > 475)
+						position = GTK_DATABOX_MARKERS_TEXT_SW;
+					else if(coord_x < 25)
+						position = GTK_DATABOX_MARKERS_TEXT_SE;
 					else
-						position = GTK_DATABOX_TEXT_S;
-					gtk_databox_marker_set_label (GTK_DATABOX_MARKER(pd->marker_right), 1,
+						position = GTK_DATABOX_MARKERS_TEXT_S;
+					gtk_databox_markers_set_label (GTK_DATABOX_MARKERS(pd->marker_right), 1,
 																				position, text, TRUE);
 					g_free((gpointer) text);
 
-					gtk_databox_redraw(pd->databox_right);
+//					gtk_databox_redraw(pd->databox_right);
+					gtk_widget_queue_draw(pd->databox_left);
 
 					int i;
 					float charge = 0.0;
